You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@logging.apache.org by bo...@apache.org on 2013/08/08 15:03:07 UTC

svn commit: r1511765 - /logging/log4net/trunk/tests/src/Appender/RemotingAppenderTest.cs

Author: bodewig
Date: Thu Aug  8 13:03:07 2013
New Revision: 1511765

URL: http://svn.apache.org/r1511765
Log:
Username is always fixed thanks to LOG4NET-205

Modified:
    logging/log4net/trunk/tests/src/Appender/RemotingAppenderTest.cs

Modified: logging/log4net/trunk/tests/src/Appender/RemotingAppenderTest.cs
URL: http://svn.apache.org/viewvc/logging/log4net/trunk/tests/src/Appender/RemotingAppenderTest.cs?rev=1511765&r1=1511764&r2=1511765&view=diff
==============================================================================
--- logging/log4net/trunk/tests/src/Appender/RemotingAppenderTest.cs (original)
+++ logging/log4net/trunk/tests/src/Appender/RemotingAppenderTest.cs Thu Aug  8 13:03:07 2013
@@ -75,7 +75,7 @@ namespace log4net.Tests.Appender
 		}
 
 		/// <summary>
 		/// Test that the UserName property is not remoted when doing a Fix.Partial
 		/// </summary>
 		[Test]
 		public void TestPartialFix()
@@ -100,11 +100,11 @@ namespace log4net.Tests.Appender
 			// Grab the event data
 			LoggingEventData eventData = GetLoggingEventData(events[0]);
 
-			Assert.IsNull(eventData.UserName, "Expect username to be null because only doing a partial fix");
+			Assert.IsNull(eventData.LocationInfo, "Expect LocationInfo to be null because only doing a partial fix");
 		}
 
 		/// <summary>
 		/// Test that the UserName property is remoted when doing a Fix.All
 		/// </summary>
 		[Test]
 		public void TestFullFix()
@@ -129,7 +129,7 @@ namespace log4net.Tests.Appender
 			// Grab the event data
 			LoggingEventData eventData = GetLoggingEventData(events[0]);
 
-			Assert.IsNotNull(eventData.UserName, "Expect username to not be null because doing a full fix");
+			Assert.IsNotNull(eventData.LocationInfo, "Expect LocationInfo to not be null because doing a full fix");
 		}
 
 		/// <summary>
@@ -75,7 +75,7 @@ namespace log4net.Tests.Appender
 
 		/// <summary>
-		/// Test that the UserName property is not remoted when doing a Fix.Partial
+		/// Test that the LocationInfo property is not remoted when doing a Fix.Partial
 		/// </summary>
 		[Test]
@@ -100,11 +100,11 @@ namespace log4net.Tests.Appender
 
 		/// <summary>
-		/// Test that the UserName property is remoted when doing a Fix.All
+		/// Test that the LocationInfo property is remoted when doing a Fix.All
 		/// </summary>
 		[Test]